@@ -1,15 +1,8 @@
 package YAML::Node;
-
-use strict;
-use warnings;
-
-use YAML::Base;
+use YAML::Base -base;
 use YAML::Tag;
 
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-our @ISA     = 'YAML::Base';
-our @EXPORT  = qw(ynode);
+our @EXPORT = qw(ynode);
 
 sub ynode {
     my $self;
@@ -68,7 +61,6 @@ sub keys {
 
 #==============================================================================
 package yaml_scalar;
-
 @yaml_scalar::ISA = qw(YAML::Node);
 
 sub new {
@@ -94,7 +86,6 @@ sub STORE {
 
 #==============================================================================
 package yaml_sequence;
-
 @yaml_sequence::ISA = qw(YAML::Node);
 
 sub new {
@@ -134,7 +125,6 @@ sub undone {
 
 #==============================================================================
 package yaml_mapping;
-
 @yaml_mapping::ISA = qw(YAML::Node);
 
 sub new {
@@ -295,7 +285,6 @@ Ingy döt Net <ingy@cpan.org>
 =head1 COPYRIGHT
 
 Copyright (c) 2006. Ingy döt Net. All rights reserved.
-
 Copyright (c) 2002. Brian Ingerson. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
